@@ -1,6 +1,5 @@
 
 import os
-import sys
 import time
 import yaml
 import datetime
@@ -16,6 +15,7 @@ from benchmark_runner.common.elasticsearch.es_operations import ESOperations
 from benchmark_runner.common.ssh.ssh import SSH
 from benchmark_runner.benchmark_operator.benchmark_operator_exceptions import OCSNonInstalled, SystemMetricsRequiredElasticSearch
 from benchmark_runner.main.environment_variables import environment_variables
+from benchmark_runner.common.clouds.IBM.ibm_operations import IBMOperations
 
 
 class BenchmarkOperatorWorkloads:
@@ -27,7 +27,6 @@ class BenchmarkOperatorWorkloads:
         self.__environment_variables_dict = environment_variables.environment_variables_dict
         self.__runner_version = self.__environment_variables_dict.get('build_version', '')
         self.__run_type = self.__environment_variables_dict.get('run_type', '')
-        self.__stop_when_workload_finish = self.__environment_variables_dict.get('stop_when_workload_finish', '')
         self.__system_metrics = self.__environment_variables_dict.get('system_metrics', '')
         self.__elasticsearch = self.__environment_variables_dict.get('elasticsearch', '')
         self.__ssh = SSH()
@@ -71,21 +70,11 @@ class BenchmarkOperatorWorkloads:
         else:
             logger.info('yaml file {} does not exist')
 
-    def __exist_for_debug(self):
-        """
-        This method check for workload exist when complete running
-        :return:
-        """
-        # Stop for debugging workload pod
-        if self.__stop_when_workload_finish == 'True':
-            return sys.exit(0)
-
     def __check_elasticsearch_exist_for_system_metrics(self):
         """
         This method check if elasticsearch exist for system metrics
         :return:
         """
-        # Stop for debugging workload pod
         if self.__system_metrics == 'True':
             if not self.__elasticsearch:
                 raise SystemMetricsRequiredElasticSearch()
@@ -270,8 +259,12 @@ class BenchmarkOperatorWorkloads:
                     'version': int(self.__runner_version.split('.')[-1]),
                     'ci_date': datetime.datetime.now().strftime(date_format)}
         if kind:
-            metadata.update({'kind': kind,
-                             'vm_os_version': 'centos8'})
+            metadata.update({'kind': kind})
+        if database:
+            metadata.update({'vm_os_version': 'centos8'})
+        else:
+            metadata.update({'vm_os_version': 'fedora34'})
+
         # for hammerdb
         if database == 'mssql':
             metadata.update({'db_version': 2019})
@@ -294,6 +287,11 @@ class BenchmarkOperatorWorkloads:
         """
         status_dict = {'failed': 0, 'pass': 1}
         metadata = self.get_metadata()
+        if ocp_resource_install_minutes_time != 0:
+            ibm_operations = IBMOperations(user=self.__environment_variables_dict.get('provision_user', ''))
+            ibm_operations.ibm_connect()
+            ocp_install_minutes_time = ibm_operations.get_ocp_install_time()
+            ibm_operations.ibm_disconnect()
         metadata.update({'status': status, 'status#': status_dict[status], 'ci_minutes_time': ci_minutes_time, 'benchmark_operator_id': benchmark_operator_id, 'benchmark_wrapper_id': benchmark_wrapper_id, 'ocp_install_minutes_time': ocp_install_minutes_time, 'ocp_resource_install_minutes_time': ocp_resource_install_minutes_time})
         self.__es_operations.upload_to_es(index='ci-status', data=metadata)
 
@@ -321,7 +319,6 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_initialized(label='app=stressng_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=stressng_workload', workload=workload)
             self.__oc.wait_for_pod_completed(label='app=stressng_workload', workload=workload)
-            self.__exist_for_debug()
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
                 self.system_metrics_collector(workload=workload)
@@ -369,7 +366,6 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_initialized(label='app=stressng_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=stressng_workload', workload=workload)
             self.__oc.wait_for_vm_completed(workload=workload)
-            self.__exist_for_debug()
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
                self.system_metrics_collector(workload=workload)
@@ -430,7 +426,6 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_initialized(label='app=uperf-bench-client', workload=workload)
             self.__oc.wait_for_ready(label='app=uperf-bench-client', workload=workload)
             self.__oc.wait_for_pod_completed(label='app=uperf-bench-client', workload=workload)
-            self.__exist_for_debug()
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
                 self.system_metrics_collector(workload=workload)
@@ -481,7 +476,6 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_initialized(label='app=uperf-bench-client', workload=workload)
             self.__oc.wait_for_ready(label='app=uperf-bench-client', workload=workload)
             self.__oc.wait_for_vm_completed(workload=workload)
-            self.__exist_for_debug()
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
                 self.system_metrics_collector(workload=workload)
@@ -535,7 +529,6 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_initialized(label='app=hammerdb_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=hammerdb_workload', workload=workload)
             self.__oc.wait_for_pod_completed(label='app=hammerdb_workload', workload=workload)
-            self.__exist_for_debug()
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
                 self.system_metrics_collector(workload=workload)
@@ -599,7 +592,6 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_initialized(label='app=hammerdb_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=hammerdb_workload', workload=workload)
             self.__oc.wait_for_vm_completed(workload=workload)
-            self.__exist_for_debug()
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
                 self.system_metrics_collector(workload=workload)
