@@ -30,9 +30,6 @@ class EnvironmentVariables:
         self._environment_variables_dict['elasticsearch'] = os.environ.get('ELASTICSEARCH', '')
         self._environment_variables_dict['elasticsearch_port'] = os.environ.get('ELASTICSEARCH_PORT', '')
 
-        # This parameter 'True'/'False' for debug workload, when its set to 'True' it will stop the workload when finishing
-        self._environment_variables_dict['stop_when_workload_finish'] = os.environ.get('STOP_WHEN_WORKLOAD_FINISH', '')
-
         # default parameter - change only if needed
         # Parameters below related to 'run_workload()'
         self._environment_variables_dict['workloads'] = ['stressng_pod', 'stressng_vm', 'stressng_kata',
@@ -49,6 +46,8 @@ class EnvironmentVariables:
         self._environment_variables_dict['system_metrics'] = os.environ.get('SYSTEM_METRICS', 'True')
         # CI status update once at the end of CI Pass/Failed
         self._environment_variables_dict['ci_status'] = os.environ.get('CI_STATUS', '')
+        # Valid run types
+        self._environment_variables_dict['run_types'] = ['test_ci', 'func_ci', 'perf_ci']
         # Run type test_ci/func_ci/perf_ci, default test_ci same environment as func_ci
         self._environment_variables_dict['run_type'] = os.environ.get('RUN_TYPE', 'test_ci')
         # end dynamic parameters - configure for local run
@@ -71,6 +70,8 @@ class EnvironmentVariables:
         # Parameters below related to 'install_ocp()'
         # MANDATORY for OCP install: install ocp version - insert version to install i.e. 'latest-4.8'
         self._environment_variables_dict['install_ocp_version'] = os.environ.get('INSTALL_OCP_VERSION', '')
+        # There are 2 steps run_ibm_ocp_ipi_installer/verify_install_complete
+        self._environment_variables_dict['install_step'] = os.environ.get('INSTALL_STEP', '')
         # dev or ga (/ocp-dev-preview/ or /ocp/ )
         self._environment_variables_dict['ocp_version_build'] = os.environ.get('OCP_VERSION_BUILD', '')
         # github repository
@@ -115,13 +116,11 @@ class EnvironmentVariables:
         # remote ssh timeout - 3 hours for installation time
         self._environment_variables_dict['provision_timeout'] = os.environ.get(f'{self.__ocp_env_flavor}_PROVISION_TIMEOUT', '10800')
         # General timeout - 1.5 hours wait for pod/vm/upload data to elasticsearch
-        self._environment_variables_dict['timeout'] = os.environ.get(f'{self.__ocp_env_flavor}_TIMEOUT', '5400')
+        self._environment_variables_dict['timeout'] = os.environ.get(f'{self.__ocp_env_flavor}_TIMEOUT', '3600')
 
         # Parameters below related to 'update_ci_status()'
         # CI run time
         self._environment_variables_dict['ci_minutes_time'] = os.environ.get('CI_MINUTES_TIME', 0)
-        # Get this parameter from install process
-        self._environment_variables_dict['ocp_install_minutes_time'] = os.environ.get('OCP_INSTALL_MINUTES_TIME', 0)
         # Get this parameter from install resource process
         self._environment_variables_dict['ocp_resource_install_minutes_time'] = os.environ.get('OCP_RESOURCE_INSTALL_MINUTES_TIME', 0)
         # benchmark-operator last commit id
@@ -158,6 +157,13 @@ class EnvironmentVariables:
         """
         return self._environment_variables_dict
 
+    @property
+    def run_types_list(self):
+        """
+        This method is getter
+        """
+        return self._environment_variables_dict['run_types']
+
     @environment_variables_dict.setter
     def environment_variables_dict(self, value: dict):
         """
